@@ -1,13 +1,13 @@
 #! /bin/sh
-exec guile-gtk -s $0 $*
+exec guile -s "$0" "$@"
 !#
 ;; Time-stamp: <1998-03-15 21:18:16 szi>
 ;;
-;; Copyright (C) 1997, 1998 Marius Vollmer
+;; Copyright (C) 1997, 1998, 1999, 2003 Free Software Foundation, Inc.
 ;; 
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU General Public License as
-;; published by the Free Software Foundation; either version 2, or (at
+;; published by the Free Software Foundation; either version 3, or (at
 ;; your option) any later version.
 ;; 
 ;; This program is distributed in the hope that it will be useful, but
@@ -16,11 +16,9 @@ exec guile-gtk -s $0 $*
 ;; General Public License for more details.
 ;; 
 ;; You should have received a copy of the GNU General Public License
-;; along with this software; see the file COPYING.  If not, write to
-;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139,
-;; USA.
-;;
-;;
+;; along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+
 ;; Calc - a HP48 like calculator
 ;;
 ;; This is a small demo application of the Guile-gtk bindings, written
@@ -187,6 +185,9 @@ exec guile-gtk -s $0 $*
 (define-module (calc)
   :use-module (gtk gtk))
 
+(if (not (defined? 'gtk-scrolled-window-add-with-viewport))
+    (define gtk-scrolled-window-add-with-viewport gtk-container-add))
+
 ;; First some utility functions.  The first saves us from writing a
 ;; million times "gtk-widget-show".  It is like gtk-widget-show but
 ;; takes any number of widgets and shows them all.
@@ -221,7 +222,7 @@ exec guile-gtk -s $0 $*
         ;; arbitrary values, with the top of the stack in the first
         ;; element.  It starts out empty.
 	(stack '()))
-
+  
     ;; Some handy operations to work on the stack.  I think you can
     ;; figure them out.
     (define (push val) (set! stack (cons val stack)))
@@ -277,7 +278,7 @@ exec guile-gtk -s $0 $*
 	  ;; changed, which leads to visible flicker.
 	  (cond ((not (string=? last-text text))
 		 (set! last-text text)
-		 (gtk-label-set echo text))))))
+		 (gtk-label-set-text echo text))))))
 
     ;; Construct a concise error message out of KEY and ARGS.  For now
     ;; we just return the KEY as a string and print a more verbose
@@ -295,11 +296,18 @@ exec guile-gtk -s $0 $*
     ;; entry is empty.  It defaults to `#t'.  The entry is cleared
     ;; after pushing the value.
     (define (activate-entry . opt-dup)
-      (let ((val (call-with-input-string (gtk-entry-get-text entry) read)))
-	(if (eof-object? val)
+      (define (read-all port)
+	(let loop ((res '())
+		   (val (read port)))
+	  (if (eof-object? val)
+	      (reverse! res)
+	      (loop (cons val res) (read port)))))
+      (let ((vals (call-with-input-string (gtk-entry-get-text entry)
+					  read-all)))
+	(if (null? vals)
 	    (if (and (or (null? opt-dup) (car opt-dup)) (not (null? stack)))
 		(push (car stack)))
-	    (push val))
+	    (for-each push vals))
 	(redisplay)
 	(gtk-entry-set-text entry "")
 	(set-echo "")))
@@ -376,7 +384,7 @@ exec guile-gtk -s $0 $*
     ;; you would write it in C.
     (gtk-window-set-title window "Calc")
     (gtk-scrolled-window-set-policy scrolled-win 'automatic 'always)
-    (gtk-container-add scrolled-win list-widget)
+    (gtk-scrolled-window-add-with-viewport scrolled-win list-widget)
     (gtk-misc-set-alignment echo 0.0 0.5)
     (gtk-widget-set-usize scrolled-win 200 120)
 
