@@ -2,11 +2,11 @@
 exec guile-gtk -e main -s $0 $*
 !#
 
-;; Copyright (C) 1997, 1998, 1999, 2002 Free Software Foundation, Inc.
+;; Copyright (C) 1997, 1998, 1999, 2002, 2007 Free Software Foundation, Inc.
 ;;
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU General Public License as
-;; published by the Free Software Foundation; either version 2 of
+;; published by the Free Software Foundation; either version 3 of
 ;; the License, or (at your option) any later version.
 ;; 
 ;; This program is distributed in the hope that it will be useful, but
@@ -14,9 +14,8 @@ exec guile-gtk -e main -s $0 $*
 ;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ;; General Public License for more details.
 ;; 
-;; You should have received a copy of the GNU General Public
-;; License along with this program; if not, write to the Free Software
-;; Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+;; You should have received a copy of the GNU General Public License
+;; along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
 ;; Time-stamp: <1998-03-15 21:34:42 szi>
@@ -41,6 +40,30 @@ exec guile-gtk -e main -s $0 $*
 (define (gtk-widget-visible? w)
   (memq 'visible (gtk-widget-flags w)))
 
+;; This is a slightly nasty hack to make a version of
+;; gtk-radio-menu-item-new-with-label-from-widget which accepts #f for the
+;; group parameter, to ask it to create a new group.
+;;
+;; In Guile-Gtk 1.2 we had our own implementation of
+;; gtk-radio-menu-item-new-with-label-from-widget, and it accepted #f in
+;; this way.  But we now use the Gtk version, and as of version 2.10 it
+;; doesn't accept NULL there.
+;;
+;; In general the current guile-gtk wrappers for radio group creation are
+;; slightly inadequate.  There's nothing that deals adequately with the
+;; GSList taken by other radio funcs.
+;;
+(define (hack-gtk-radio-menu-item-new-with-label-from-widget group str)
+  (if group
+      (gtk-radio-menu-item-new-with-label-from-widget group str)
+
+      (let ((item  (gtk-widget-new 'GtkRadioMenuItem))
+	    (label (gtk-widget-new 'GtkLabel
+				   #:label str #:xalign 0 #:yalign 0.5)))
+	(gtk-widget-show label)
+	(gtk-container-add item label)
+	item)))
+
 (define (make-dialog-creator inner-creator)
   (let ((window #f))
     (lambda ()
@@ -243,7 +266,7 @@ exec guile-gtk -e main -s $0 $*
 			(lambda () (gtk-clist-undo-selection clist)))
     (gtk-box-pack-start box2 (gtk-label-new "Selection Mode :") #f #f 0)
 
-    (set! button (gtk-radio-menu-item-new-with-label-from-widget #f "Single"))
+    (set! button (hack-gtk-radio-menu-item-new-with-label-from-widget #f "Single"))
     (gtk-menu-append menu button)
     (gtk-widget-show button)
     (gtk-signal-connect button "activate" 
@@ -358,7 +381,7 @@ exec guile-gtk -e main -s $0 $*
 (define-test create-radio-buttons "radio buttons"
   (let ((group #f))
     (define (radio-maker label)
-      (set! group (gtk-radio-button-new-with-label group label))
+      (set! group (hack-gtk-radio-menu-item-new-with-label-from-widget group label))
       group)
     (make-three-buttons outer-box radio-maker))
   '())
@@ -429,7 +452,8 @@ exec guile-gtk -e main -s $0 $*
 	(do ((i 0 (1+ i))
 	     (j 1 (1+ j)))
 	    ((= i 6))
-	  (let ((menuitem (gtk-radio-menu-item-new-with-label group
+	  (let ((menuitem (hack-gtk-radio-menu-item-new-with-label-from-widget
+			   group
 			   (string-append "item " (number->string depth)
 					  " - " (number->string j)))))
 	    (set! group menuitem)
@@ -574,7 +598,7 @@ exec guile-gtk -e main -s $0 $*
 
     (gtk-list-set-selection-mode lyst 'multiple)
     (gtk-list-set-selection-mode lyst 'browse)
-    (gtk-container-add scrolled-win lyst)
+    (gtk-scrolled-window-add-with-viewport scrolled-win lyst)
     (gtk-widget-show lyst)
 
     (for-each (lambda (i)
@@ -856,11 +880,12 @@ exec guile-gtk -e main -s $0 $*
 	(count 0)
 	(label (gtk-label-new "")))
     (define (set-label)
-      (gtk-label-set label
-		     (string-append "count: " (number->string count))))
+      (gtk-label-set-text label
+			  (string-append "count: " (number->string count))))
     (define (tick)
       (set! count (1+ count))
-      (set-label))
+      (set-label)
+      #t) ;; keep calling
     (define (start)
       (if (not tag) (set! tag (adder tick))))
     (define (stop)
