@@ -1,9 +1,9 @@
 /*
- * Copyright 2003, 2006 Free Software Foundation, Inc.
+ * Copyright 2003, 2006, 2007 Free Software Foundation, Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
+ * the Free Software Foundation; either version 3, or (at your option)
  * any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -12,8 +12,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this software; see the file COPYING.  If not, write to
- * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <gdk-pixbuf/gdk-pixbuf.h>
@@ -21,7 +20,7 @@
 
 #include <libguile.h>
 
-#include "compat.h"
+#include "guile-gtk-compat.h"
 #include "guile-gtk.h"
 #include "gdk-pixbuf-support.h"
 
