@@ -1,10 +1,10 @@
 /*
- * Copyright (C) 1997, 1998, 1999, 2002, 2003, 2004, 2005, 2006 Free
+ * Copyright (C) 1997, 1998, 1999, 2002, 2003, 2004, 2005, 2006, 2007 Free
  * Software Foundation, Inc.
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
+ * the Free Software Foundation; either version 3, or (at your option)
  * any later version.
  * 
  * This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with this software; see the file COPYING.  If not, write to
- * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #define GDK_ENABLE_BROKEN 1  /* ask for gdk_image_new_bitmap */
@@ -26,7 +25,7 @@
 #include <glib-object.h>
 #include <gdk/gdkx.h> /* for GDK_WINDOW_XID */
 
-#include "compat.h"
+#include "guile-gtk-compat.h"
 #include "gtk-threads.h"
 #include <string.h>
 
