@@ -1,10 +1,10 @@
 /*
- * Copyright (C) 1997, 1998, 2000, 2001, 2002, 2003, 2004, 2006 Free Software
+ * Copyright (C) 1997, 1998, 2000, 2001, 2002, 2003, 2004, 2006, 2007 Free Software
  * Foundation, Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
+ * the Free Software Foundation; either version 3, or (at your option)
  * any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this software; see the file COPYING.  If not, write to
- * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -44,13 +43,6 @@ gtk_menu_popup_interp (GtkMenu *menu,
 		  NULL, NULL, button, activate_time);
 }
 
-GtkWidget*
-gtk_radio_menu_item_new_from_widget (GtkRadioMenuItem *group)
-{
-  GSList *g = group? gtk_radio_menu_item_group (group) : NULL;
-  return gtk_radio_menu_item_new (g);
-}
-
 GdkColor*
 gdk_color_parse_interp (char *spec)
 {
