@@ -1,10 +1,10 @@
 /*
- * Copyright (C) 1997, 1998, 1999, 2000, 2002, 2003, 2004, 2005, 2006 Free
- * Software Foundation, Inc.
+ * Copyright (C) 1997, 1998, 1999, 2000, 2002, 2003, 2004, 2005, 2006, 2007
+ * Free Software Foundation, Inc.
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
+ * the Free Software Foundation; either version 3, or (at your option)
  * any later version.
  * 
  * This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with this software; see the file COPYING.  If not, write to
- * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -34,7 +33,21 @@
 #include <libguile/tags.h>
 
 #include "guile-gtk.h"
-#include "compat.h"
+#include "guile-gtk-compat.h"
+
+
+/* g_object_ref_sink is new in glib some time post 2.6.
+   In the past the floating reference stuff was only within GtkObject. */
+#if ! HAVE_G_OBJECT_REF_SINK
+static gpointer
+g_object_ref_sink (gpointer object)
+{
+  g_object_ref (G_OBJECT (object));
+  if (GTK_IS_OBJECT (object) && GTK_OBJECT_FLOATING (object))
+    gtk_object_sink (GTK_OBJECT (object));
+  return object;
+}
+#endif
 
 
 /* Define this to enable some output during GC and other interesting
@@ -105,7 +118,7 @@ sgtk_symbol_to_locale_string (SCM obj)
    The idea here is that the contents of a string are picked out with
    scm_to_locale_string and then that malloced block is held in a cstr smob
    object.  This is done through the "convert" attribute in
-   build-guile-gtk-1.2 (for string and cstring) and in sgtk_type_info (for
+   build-guile-gtk-2.0 (for string and cstring) and in sgtk_type_info (for
    GTK_TYPE_STRING).
 
    A smob object is a pretty easy way to get stuff freed when no longer in
@@ -113,7 +126,7 @@ sgtk_symbol_to_locale_string (SCM obj)
 
    The alternative would be frames with scm_dynwind_begin.  That might even
    be the best idea for the straightforward bits of code generated by
-   build-guile-gtk-1.2.  But for a few special cases like gtk-signal-emit
+   build-guile-gtk-2.0.  But for a few special cases like gtk-signal-emit
    which do a callback to scheme code some care is needed to ensure that
    continuations can still be captured like they have been in the past.
    (There's always been restrictions on that stuff, but don't want to
@@ -1197,8 +1210,8 @@ sgtk_scm2senum (SCM obj, sgtk_senum_info *info)
 static long tc16_boxed;
 
 #define BOXED_P(x)     (SCM_NIMP(x) && (SCM_TYP16(x) == tc16_boxed))
-#define BOXED_SEQNO(x) (((guint)SCM_CAR(x))>>16)
-#define BOXED_PTR(x)   ((gpointer)SCM_CDR(x))
+#define BOXED_SEQNO(x) (((guint) SCM_CELL_WORD_0(x)) >> 16)
+#define BOXED_PTR(x)   ((gpointer) SCM_CELL_WORD_1(x))
 #define BOXED_INFO(x)  ((sgtk_boxed_info*)must_get_type_info(BOXED_SEQNO(x)))
 #define BOXED_SET_PTR(x,d) SCM_SETCDR(x,d)
 
@@ -1988,6 +2001,54 @@ sgtk_scm2raw (SCM obj, int pos, char* func)
 }
 #undef FUNC_NAME
 
+
+/* helpers for G_TYPE_STRV */
+
+/* return true if obj is a list of strings (a proper list) */
+int
+sgtk_valid_strv (SCM obj)
+{
+  if (scm_is_false (scm_list_p (obj)))
+    return 0;
+  for ( ; ! scm_is_null (obj); obj = scm_cdr (obj))
+    if (! scm_is_string (scm_car (obj)))
+      return 0;
+  return 1;
+}
+
+/* Return a C array of strings formed from a scheme list of strings.
+   Each string and the array itself are malloced blocks, ready for
+   g_strfreev() to free.  LST can be #f, which is returned as NULL (the
+   about dialog for instance distinguishes between NULL and a zero-length
+   array of strings).  */
+char **
+sgtk_to_strv (SCM lst)
+{
+  if (scm_is_false (lst))
+    return NULL;
+  else
+    {
+      size_t len = scm_to_int (scm_length (lst));
+      char **strv = scm_malloc (sizeof (char *) * (len + 1));
+      char **p;
+      for (p = strv; ! scm_is_null (lst); lst = scm_cdr (lst), p++)
+        p[0] = scm_to_locale_string (scm_car (lst));
+      p[0] = NULL;
+      return strv;
+    }
+}
+
+/* Return a scheme list of strings formed from a char** array of C strings.
+   "strv" can be NULL. */
+SCM
+sgtk_from_strv (char **strv)
+{
+  if (strv == NULL)
+    return SCM_BOOL_F;
+  else
+    return scm_makfromstrs (-1, strv);
+}
+
 /* converting between SCM and GtkArg */
 
 SCM
@@ -2025,9 +2086,12 @@ sgtk_arg2scm (GtkArg *a, int free_mem)
       return sgtk_flags2scm (GTK_VALUE_FLAGS(*a),
 			     (sgtk_enum_info *)sgtk_find_type_info (a->type));
     case GTK_TYPE_BOXED:
-      return sgtk_boxed2scm (GTK_VALUE_BOXED(*a),
-			     (sgtk_boxed_info *)sgtk_find_type_info (a->type),
-			     TRUE);
+      if (a->type == G_TYPE_STRV)
+        return sgtk_from_strv ((char **) GTK_VALUE_BOXED(*a));
+      else
+        return sgtk_boxed2scm (GTK_VALUE_BOXED(*a),
+                               (sgtk_boxed_info *)sgtk_find_type_info (a->type),
+                               TRUE);
     case G_TYPE_OBJECT:
       return sgtk_wrap_gtkobj ((GObject *) GTK_VALUE_OBJECT(*a));
     default:
@@ -2074,9 +2138,12 @@ sgtk_gvalue2scm (const GValue *value, int free_mem)
       return sgtk_enum2scm (g_value_get_flags (value),
                             (sgtk_enum_info *) sgtk_find_type_info (type));
     case G_TYPE_BOXED:
-      return sgtk_boxed2scm (g_value_get_boxed (value),
-			     (sgtk_boxed_info *) sgtk_find_type_info (type),
-			     TRUE);
+      if (type == G_TYPE_STRV)
+        return sgtk_from_strv ((char **) g_value_get_boxed (value));
+      else
+        return sgtk_boxed2scm (g_value_get_boxed (value),
+                               (sgtk_boxed_info *) sgtk_find_type_info (type),
+                               TRUE);
     case G_TYPE_OBJECT:
       return sgtk_wrap_gtkobj (g_value_get_object (value));
     default:
@@ -2120,8 +2187,11 @@ sgtk_valid_for_type (GType type, SCM obj)
       return sgtk_valid_flags (obj, ((sgtk_enum_info *)
 				     sgtk_find_type_info (type)));
     case GTK_TYPE_BOXED:
-      return sgtk_valid_boxed (obj, ((sgtk_boxed_info *)
-				     sgtk_find_type_info (type)));
+      if (type == G_TYPE_STRV)
+        return sgtk_valid_strv (obj);
+      else
+        return sgtk_valid_boxed (obj, ((sgtk_boxed_info *)
+                                       sgtk_find_type_info (type)));
       break;
 #if 0
       /* Gone in Gtk 2 */
@@ -2183,11 +2253,14 @@ sgtk_scm2ret (GtkArg *a, SCM obj)
 		       SCM_ARG1, "scm->gtk");
       break;
     case GTK_TYPE_BOXED:
-      *GTK_RETLOC_BOXED(*a) = sgtk_scm2boxed (obj);
+      if (a->type == G_TYPE_STRV)
+        *GTK_RETLOC_BOXED(*a) = sgtk_to_strv (obj);
+      else
+        *GTK_RETLOC_BOXED(*a) = sgtk_scm2boxed (obj);
       break;
     case G_TYPE_OBJECT:
       SCM_ASSERT (sgtk_is_a_gtkobj (a->type, obj), obj, SCM_ARG1, "scm->gtk");
-      *GTK_RETLOC_OBJECT(*a) = sgtk_get_gtkobj (obj);
+      *GTK_RETLOC_OBJECT(*a) = (void *) sgtk_get_gtkobj (obj);
       break;
     default:
       fprintf (stderr, "unhandled return type %s\n", gtk_type_name (a->type));
@@ -2253,7 +2326,10 @@ sgtk_scm2gvalue (GValue *v, SCM obj)
       g_value_set_enum (v, sgtk_scm2flags (obj, (sgtk_enum_info *)sgtk_find_type_info (type), SCM_ARGn, "scm->gtk"));
       break;
     case G_TYPE_BOXED:
-      g_value_set_boxed (v, sgtk_scm2boxed (obj));
+      if (type == G_TYPE_STRV)
+        g_value_set_boxed (v, sgtk_to_strv (obj));
+      else
+        g_value_set_boxed (v, sgtk_scm2boxed (obj));
       break;
     case G_TYPE_OBJECT:
       SCM_ASSERT (sgtk_is_a_gtkobj (type, obj), obj, SCM_ARGn, "scm->gtk");
@@ -2320,6 +2396,19 @@ struct callback_info {
   GtkArg *args;
 };
 
+static void
+warn_return_unspecified (SCM proc)
+{
+  SCM port, str;
+  char *c_str;
+  port = scm_open_output_string ();
+  scm_write (proc, port);
+  str = scm_get_output_string (port);
+  c_str = scm_to_locale_string (str);
+  g_warning ("scheme callback returning #<unspecified> where value expected: %s", c_str);
+  free (c_str);
+}
+
 static SCM
 inner_callback_marshal (void *data)
 {
@@ -2335,7 +2424,14 @@ inner_callback_marshal (void *data)
     ans = scm_apply (SCM_CAR(callback_trampoline),
 		     scm_cons2 (info->proc, args, SCM_EOL), SCM_EOL);
   if (info->args[info->n_args].type != GTK_TYPE_NONE)
-    sgtk_scm2ret (info->args+info->n_args, ans);
+    {
+      /* warn about `unspecified' since this usually means the program forgot
+         to return something, eg. a bool from a Gdk event */
+      if (scm_is_eq (ans, SCM_UNSPECIFIED))
+        warn_return_unspecified (info->proc);
+
+      sgtk_scm2ret (info->args+info->n_args, ans);
+    }
 
   for (i = 0; i < info->n_args; ++i, args = SCM_CDR (args))
     sgtk_arg_cleanup (info->args+i, SCM_CAR (args));
@@ -2373,6 +2469,37 @@ sgtk_callback_marshal (GtkObject *obj,
 		     &stack_item);
 }
 
+/* "data" is the SCM procedure to call.
+   This uses inner_callback_marshal() because it can do most of the work
+   needed. */
+void
+sgtk_about_dialog_activate_link_marshal (GtkAboutDialog *about,
+                                         const gchar *link,
+                                         gpointer data)
+{
+  SCM_STACKITEM stack_item;
+  struct callback_info info;
+  GtkArg a[3];
+
+  a[0].type = GTK_TYPE_OBJECT;
+  a[0].name = "about";
+  GTK_VALUE_OBJECT(a[0]) = (GtkObject *) about;
+
+  a[1].type = GTK_TYPE_STRING;
+  a[1].name = "link";
+  GTK_VALUE_STRING(a[1]) = (char *) link;
+
+  a[2].type = GTK_TYPE_NONE;
+
+  info.proc = SCM_PACK (data);
+  info.n_args = 2;
+  info.args = a;
+
+  scm_internal_cwdr ((scm_t_catch_body)inner_callback_marshal, &info,
+		     scm_handle_by_message_noexit, "gtk",
+		     &stack_item);
+}
+
 struct closure_info {
   SCM proc;
   GValue *return_value;
@@ -2401,7 +2528,14 @@ inner_closure_marshal (void *data)
      example from gtk_binding_entry_activate().  Believe this means there's
      no return wanted or expected.  */
   if (info->return_value != NULL && G_VALUE_TYPE (info->return_value) != 0)
-    sgtk_scm2gvalue (info->return_value, ans);
+    {
+      /* warn about `unspecified' since this usually means the program forgot
+         to return something, eg. a bool from a Gdk event */
+      if (scm_is_eq (ans, SCM_UNSPECIFIED))
+        warn_return_unspecified (info->proc);
+
+      sgtk_scm2gvalue (info->return_value, ans);
+    }
 
   return SCM_UNSPECIFIED;
 }
