@@ -1,9 +1,9 @@
-/* Copyright (C) 1997, 1998, 1999, 2003, 2004, 2006 Free Software
+/* Copyright (C) 1997, 1998, 1999, 2003, 2004, 2006, 2007 Free Software
  * Foundation, Inc.
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
+ * the Free Software Foundation; either version 3, or (at your option)
  * any later version.
  * 
  * This program is distributed in the hope that it will be useful,
@@ -12,8 +12,7 @@
  * GNU General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with this software; see the file COPYING.  If not, write to
- * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef GUILE_GTK_H
@@ -211,6 +210,14 @@ void sgtk_callback_marshal (GtkObject *,
 void sgtk_callback_destroy (gpointer data);
 SCM sgtk_callback_trampoline (SCM new_trampoline);
 
+void sgtk_about_dialog_activate_link_marshal (GtkAboutDialog *about,
+                                              const gchar *link,
+                                              gpointer data);
+void gtk_about_dialog_set_email_hook_interp (SCM func);
+void gtk_about_dialog_set_url_hook_interp (SCM func);
+void gtk_link_button_set_uri_hook_interp (SCM func);
+
+
 void sgtk_closure_marshal (GClosure *closure,
                            GValue *return_value,
                            guint n_param_values,
@@ -368,8 +375,6 @@ void gtk_menu_popup_interp (GtkMenu *menu,
 			    gint button,
 			    guint32 activate_time);
 
-GtkWidget* gtk_radio_menu_item_new_from_widget (GtkRadioMenuItem *group);
-
 GdkColor *gdk_color_new (void);
 GdkColor *gdk_color_parse_interp (char *spec);
 GdkColor *gtk_style_get_white_interp (GtkStyle *style);
