@@ -1,10 +1,10 @@
 /* Guile Gtk C code for tests.
 
-   Copyright (C) 2006 Free Software Foundation, Inc.
+   Copyright (C) 2006, 2007 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
-   Free Software Foundation; either version 2 of the License, or (at your
+   Free Software Foundation; either version 3 of the License, or (at your
    option) any later version.
 
    This program is distributed in the hope that it will be useful, but
@@ -12,9 +12,8 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
    Public License for more details.
 
-   You should have received a copy of the GNU General Public License along
-   with this program; if not, write to the Free Software Foundation, Inc.,
-   59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.  */
+   You should have received a copy of the GNU General Public License
+   along with this program.  If not, see <http://www.gnu.org/licenses/>. */
 
 #include "config.h"
 
@@ -24,7 +23,7 @@
 
 #include <libguile.h>
 
-#include "compat.h"
+#include "guile-gtk-compat.h"
 
 
 SCM_DEFINE (tests_mallinfo_uordblks, "mallinfo-uordblks", 0, 0, 0,
